
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)

A #PopplerPageTransition structures describes a visual transition
to use when moving between pages during a presentation
-}

module GI.Poppler.Structs.PageTransition
    ( 

-- * Exported types
    PageTransition(..)                      ,
    noPageTransition                        ,


 -- * Methods
-- ** pageTransitionCopy
    pageTransitionCopy                      ,


-- ** pageTransitionFree
    pageTransitionFree                      ,


-- ** pageTransitionNew
    pageTransitionNew                       ,




 -- * Properties
-- ** Alignment
    pageTransitionReadAlignment             ,


-- ** Angle
    pageTransitionReadAngle                 ,


-- ** Direction
    pageTransitionReadDirection             ,


-- ** Duration
    pageTransitionReadDuration              ,


-- ** Rectangular
    pageTransitionReadRectangular           ,


-- ** Scale
    pageTransitionReadScale                 ,


-- ** Type
    pageTransitionReadType                  ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Poppler.Types
import GI.Poppler.Callbacks

newtype PageTransition = PageTransition (ForeignPtr PageTransition)
foreign import ccall "poppler_page_transition_get_type" c_poppler_page_transition_get_type :: 
    IO GType

instance BoxedObject PageTransition where
    boxedType _ = c_poppler_page_transition_get_type

noPageTransition :: Maybe PageTransition
noPageTransition = Nothing

pageTransitionReadType :: PageTransition -> IO PageTransitionType
pageTransitionReadType s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 0) :: IO CUInt
    let val' = (toEnum . fromIntegral) val
    return val'

pageTransitionReadAlignment :: PageTransition -> IO PageTransitionAlignment
pageTransitionReadAlignment s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 4) :: IO CUInt
    let val' = (toEnum . fromIntegral) val
    return val'

pageTransitionReadDirection :: PageTransition -> IO PageTransitionDirection
pageTransitionReadDirection s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 8) :: IO CUInt
    let val' = (toEnum . fromIntegral) val
    return val'

pageTransitionReadDuration :: PageTransition -> IO Int32
pageTransitionReadDuration s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 12) :: IO Int32
    return val

pageTransitionReadAngle :: PageTransition -> IO Int32
pageTransitionReadAngle s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 16) :: IO Int32
    return val

pageTransitionReadScale :: PageTransition -> IO Double
pageTransitionReadScale s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 24) :: IO CDouble
    let val' = realToFrac val
    return val'

pageTransitionReadRectangular :: PageTransition -> IO Bool
pageTransitionReadRectangular s = withManagedPtr s $ \ptr -> do
    val <- peek (ptr `plusPtr` 32) :: IO CInt
    let val' = (/= 0) val
    return val'

-- method PageTransition::new
-- method type : Constructor
-- Args : []
-- Lengths : []
-- hInArgs : []
-- returnType : TInterface "Poppler" "PageTransition"
-- throws : False
-- Skip return : False

foreign import ccall "poppler_page_transition_new" poppler_page_transition_new :: 
    IO (Ptr PageTransition)


pageTransitionNew ::
    (MonadIO m) =>
    m PageTransition
pageTransitionNew  = liftIO $ do
    result <- poppler_page_transition_new
    checkUnexpectedReturnNULL "poppler_page_transition_new" result
    result' <- (wrapBoxed PageTransition) result
    return result'

-- method PageTransition::copy
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Poppler" "PageTransition", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Poppler" "PageTransition", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Poppler" "PageTransition"
-- throws : False
-- Skip return : False

foreign import ccall "poppler_page_transition_copy" poppler_page_transition_copy :: 
    Ptr PageTransition ->                   -- _obj : TInterface "Poppler" "PageTransition"
    IO (Ptr PageTransition)


pageTransitionCopy ::
    (MonadIO m) =>
    PageTransition ->                       -- _obj
    m PageTransition
pageTransitionCopy _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    result <- poppler_page_transition_copy _obj'
    checkUnexpectedReturnNULL "poppler_page_transition_copy" result
    result' <- (wrapBoxed PageTransition) result
    touchManagedPtr _obj
    return result'

-- method PageTransition::free
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "Poppler" "PageTransition", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "Poppler" "PageTransition", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "poppler_page_transition_free" poppler_page_transition_free :: 
    Ptr PageTransition ->                   -- _obj : TInterface "Poppler" "PageTransition"
    IO ()


pageTransitionFree ::
    (MonadIO m) =>
    PageTransition ->                       -- _obj
    m ()
pageTransitionFree _obj = liftIO $ do
    let _obj' = unsafeManagedPtrGetPtr _obj
    poppler_page_transition_free _obj'
    touchManagedPtr _obj
    return ()


